---
sidebar_label: configuration
title: soil.configuration
---

Defines the configuration for Soil

## SoilConfiguration Objects

```python
class SoilConfiguration(NamedTuple)
```

Soil configuration class

